[][src]Enum marked_yaml::types::Node

pub enum Node {
    Scalar(MarkedScalarNode),
    Mapping(MarkedMappingNode),
    Sequence(MarkedSequenceNode),
}

A marked YAML node

NOTE: Nodes are considered equal even if they don't come from the same place. i.e. their spans are ignored for equality and hashing

use marked_yaml::parse_yaml;
let node = parse_yaml(100, "{foo: bar}").unwrap();
assert!(node.as_mapping().is_some());

Variants

A YAML scalar

You can test if a node is a scalar, and retrieve it as one if you so wish.

A YAML mapping

You can test if a node is a mapping, and retrieve it as one if you so wish.

A YAML sequence

You can test if a node is a sequence, and retrieve it as one if you so wish.

Methods

impl Node[src]

pub fn span(&self) -> &Span[src]

Retrieve the Span from the contained Node

let node: Node = "foobar".into();
let span = node.span();
assert_eq!(span.start(), None);

pub fn span_mut(&mut self) -> &mut Span[src]

Retrieve the Span from the contained Node, mutably

let mut node: Node = "foobar".into();
let mut span = node.span_mut();
assert_eq!(span.start(), None);
span.set_start(Some(Marker::new(0, 1, 0)));
assert_eq!(span.start(), Some(&Marker::new(0, 1, 0)));

pub fn as_scalar(&self) -> Option<&MarkedScalarNode>[src]

Retrieve the scalar from this node if there is one

let node: Node = "foobar".into();
let scalar = node.as_scalar();
assert!(scalar.is_some());

pub fn as_sequence(&self) -> Option<&MarkedSequenceNode>[src]

Retrieve the sequence from this node if there is one

let node: Node = vec!["foobar"].into();
let sequence = node.as_sequence();
assert!(sequence.is_some());

pub fn as_mapping(&self) -> Option<&MarkedMappingNode>[src]

Retrieve the mapping from this node if there is one

let node: Node = parse_yaml(0, "{foobar: baz}").unwrap();
let mapping = node.as_mapping();
assert!(mapping.is_some());

pub fn as_scalar_mut(&mut self) -> Option<&mut MarkedScalarNode>[src]

Retrieve the scalar from this node if there is one, mutably

let mut node: Node = "foobar".into();
let mut scalar = node.as_scalar_mut();
assert!(scalar.is_some());

pub fn as_sequence_mut(&mut self) -> Option<&mut MarkedSequenceNode>[src]

Retrieve the sequence from this node if there is one, mutably

let mut node: Node = vec!["foobar"].into();
let mut sequence = node.as_sequence_mut();
assert!(sequence.is_some());

pub fn as_mapping_mut(&mut self) -> Option<&mut MarkedMappingNode>[src]

Retrieve the mapping from this node if there is one, mutably

let mut node: Node = parse_yaml(0, "{foobar: baz}").unwrap();
let mut mapping = node.as_mapping_mut();
assert!(mapping.is_some());